from .api import Trace
from .client.http_client import HTTPClient


class RCABenchSDK:
    def __init__(self, base_url: str, api_version: str = "/api/v1"):
        client = HTTPClient(base_url.rstrip("/"))
        self.trace = Trace(client, api_version)



# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from rcabench.openapi.models.dto_assign_user_to_project_request import DtoAssignUserToProjectRequest
from rcabench.openapi.models.dto_create_user_request import DtoCreateUserRequest
from rcabench.openapi.models.dto_generic_response_any import DtoGenericResponseAny
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_user_response import DtoGenericResponseDtoSearchResponseDtoUserResponse
from rcabench.openapi.models.dto_generic_response_dto_user_list_response import DtoGenericResponseDtoUserListResponse
from rcabench.openapi.models.dto_generic_response_dto_user_response import DtoGenericResponseDtoUserResponse
from rcabench.openapi.models.dto_update_user_request import DtoUpdateUserRequest
from rcabench.openapi.models.dto_user_search_request import DtoUserSearchRequest

from rcabench.openapi.api_client import ApiClient, RequestSerialized
from rcabench.openapi.api_response import ApiResponse
from rcabench.openapi.rest import RESTResponseType


class UsersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://rcabench.openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v2_users_get(
        self,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Page size")] = None,
        status: Annotated[Optional[StrictInt], Field(description="Filter by status")] = None,
        is_active: Annotated[Optional[StrictBool], Field(description="Filter by active status")] = None,
        username: Annotated[Optional[StrictStr], Field(description="Filter by username")] = None,
        email: Annotated[Optional[StrictStr], Field(description="Filter by email")] = None,
        full_name: Annotated[Optional[StrictStr], Field(description="Filter by full name")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoUserListResponse:
        """List users

        Get paginated list of users with optional filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param status: Filter by status
        :type status: int
        :param is_active: Filter by active status
        :type is_active: bool
        :param username: Filter by username
        :type username: str
        :param email: Filter by email
        :type email: str
        :param full_name: Filter by full name
        :type full_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_get_serialize(
            page=page,
            size=size,
            status=status,
            is_active=is_active,
            username=username,
            email=email,
            full_name=full_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserListResponse",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_get_with_http_info(
        self,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Page size")] = None,
        status: Annotated[Optional[StrictInt], Field(description="Filter by status")] = None,
        is_active: Annotated[Optional[StrictBool], Field(description="Filter by active status")] = None,
        username: Annotated[Optional[StrictStr], Field(description="Filter by username")] = None,
        email: Annotated[Optional[StrictStr], Field(description="Filter by email")] = None,
        full_name: Annotated[Optional[StrictStr], Field(description="Filter by full name")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoUserListResponse]:
        """List users

        Get paginated list of users with optional filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param status: Filter by status
        :type status: int
        :param is_active: Filter by active status
        :type is_active: bool
        :param username: Filter by username
        :type username: str
        :param email: Filter by email
        :type email: str
        :param full_name: Filter by full name
        :type full_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_get_serialize(
            page=page,
            size=size,
            status=status,
            is_active=is_active,
            username=username,
            email=email,
            full_name=full_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserListResponse",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_get_without_preload_content(
        self,
        page: Annotated[Optional[StrictInt], Field(description="Page number")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Page size")] = None,
        status: Annotated[Optional[StrictInt], Field(description="Filter by status")] = None,
        is_active: Annotated[Optional[StrictBool], Field(description="Filter by active status")] = None,
        username: Annotated[Optional[StrictStr], Field(description="Filter by username")] = None,
        email: Annotated[Optional[StrictStr], Field(description="Filter by email")] = None,
        full_name: Annotated[Optional[StrictStr], Field(description="Filter by full name")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List users

        Get paginated list of users with optional filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param status: Filter by status
        :type status: int
        :param is_active: Filter by active status
        :type is_active: bool
        :param username: Filter by username
        :type username: str
        :param email: Filter by email
        :type email: str
        :param full_name: Filter by full name
        :type full_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_get_serialize(
            page=page,
            size=size,
            status=status,
            is_active=is_active,
            username=username,
            email=email,
            full_name=full_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserListResponse",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_get_serialize(
        self,
        page,
        size,
        status,
        is_active,
        username,
        email,
        full_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        if is_active is not None:
            
            _query_params.append(('is_active', is_active))
            
        if username is not None:
            
            _query_params.append(('username', username))
            
        if email is not None:
            
            _query_params.append(('email', email))
            
        if full_name is not None:
            
            _query_params.append(('full_name', full_name))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/users',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v2_users_id_delete(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseAny:
        """Delete user

        Delete a user (soft delete by setting status to -1)

        :param id: User ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_id_delete_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseAny]:
        """Delete user

        Delete a user (soft delete by setting status to -1)

        :param id: User ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_id_delete_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete user

        Delete a user (soft delete by setting status to -1)

        :param id: User ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_id_delete_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/users/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v2_users_id_get(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoUserResponse:
        """Get user by ID

        Get detailed information about a specific user

        :param id: User ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_id_get_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoUserResponse]:
        """Get user by ID

        Get detailed information about a specific user

        :param id: User ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_id_get_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get user by ID

        Get detailed information about a specific user

        :param id: User ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_id_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/users/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v2_users_id_projects_post(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        request: Annotated[DtoAssignUserToProjectRequest, Field(description="Project assignment request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseAny:
        """Assign user to project

        Assign a user to a project with a specific role

        :param id: User ID (required)
        :type id: int
        :param request: Project assignment request (required)
        :type request: DtoAssignUserToProjectRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_projects_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_id_projects_post_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        request: Annotated[DtoAssignUserToProjectRequest, Field(description="Project assignment request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseAny]:
        """Assign user to project

        Assign a user to a project with a specific role

        :param id: User ID (required)
        :type id: int
        :param request: Project assignment request (required)
        :type request: DtoAssignUserToProjectRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_projects_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_id_projects_post_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        request: Annotated[DtoAssignUserToProjectRequest, Field(description="Project assignment request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Assign user to project

        Assign a user to a project with a specific role

        :param id: User ID (required)
        :type id: int
        :param request: Project assignment request (required)
        :type request: DtoAssignUserToProjectRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_projects_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_id_projects_post_serialize(
        self,
        id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/users/{id}/projects',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v2_users_id_projects_project_id_delete(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        project_id: Annotated[StrictInt, Field(description="Project ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseAny:
        """Remove user from project

        Remove a user from a project

        :param id: User ID (required)
        :type id: int
        :param project_id: Project ID (required)
        :type project_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_projects_project_id_delete_serialize(
            id=id,
            project_id=project_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_id_projects_project_id_delete_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        project_id: Annotated[StrictInt, Field(description="Project ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseAny]:
        """Remove user from project

        Remove a user from a project

        :param id: User ID (required)
        :type id: int
        :param project_id: Project ID (required)
        :type project_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_projects_project_id_delete_serialize(
            id=id,
            project_id=project_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_id_projects_project_id_delete_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        project_id: Annotated[StrictInt, Field(description="Project ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Remove user from project

        Remove a user from a project

        :param id: User ID (required)
        :type id: int
        :param project_id: Project ID (required)
        :type project_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_projects_project_id_delete_serialize(
            id=id,
            project_id=project_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseAny",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_id_projects_project_id_delete_serialize(
        self,
        id,
        project_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if project_id is not None:
            _path_params['project_id'] = project_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/users/{id}/projects/{project_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v2_users_id_put(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        request: Annotated[DtoUpdateUserRequest, Field(description="User update request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoUserResponse:
        """Update user

        Update user information (partial update supported)

        :param id: User ID (required)
        :type id: int
        :param request: User update request (required)
        :type request: DtoUpdateUserRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_put_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_id_put_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        request: Annotated[DtoUpdateUserRequest, Field(description="User update request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoUserResponse]:
        """Update user

        Update user information (partial update supported)

        :param id: User ID (required)
        :type id: int
        :param request: User update request (required)
        :type request: DtoUpdateUserRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_put_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_id_put_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="User ID")],
        request: Annotated[DtoUpdateUserRequest, Field(description="User update request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update user

        Update user information (partial update supported)

        :param id: User ID (required)
        :type id: int
        :param request: User update request (required)
        :type request: DtoUpdateUserRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_id_put_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_id_put_serialize(
        self,
        id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v2/users/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v2_users_post(
        self,
        request: Annotated[DtoCreateUserRequest, Field(description="User creation request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoUserResponse:
        """Create a new user

        Create a new user account with specified details

        :param request: User creation request (required)
        :type request: DtoCreateUserRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '409': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_post_with_http_info(
        self,
        request: Annotated[DtoCreateUserRequest, Field(description="User creation request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoUserResponse]:
        """Create a new user

        Create a new user account with specified details

        :param request: User creation request (required)
        :type request: DtoCreateUserRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '409': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_post_without_preload_content(
        self,
        request: Annotated[DtoCreateUserRequest, Field(description="User creation request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a new user

        Create a new user account with specified details

        :param request: User creation request (required)
        :type request: DtoCreateUserRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "DtoGenericResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '409': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/users',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v2_users_search_post(
        self,
        request: Annotated[DtoUserSearchRequest, Field(description="User search request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoSearchResponseDtoUserResponse:
        """Search users

        Search users with complex filtering and sorting

        :param request: User search request (required)
        :type request: DtoUserSearchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_search_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoSearchResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v2_users_search_post_with_http_info(
        self,
        request: Annotated[DtoUserSearchRequest, Field(description="User search request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoSearchResponseDtoUserResponse]:
        """Search users

        Search users with complex filtering and sorting

        :param request: User search request (required)
        :type request: DtoUserSearchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_search_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoSearchResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v2_users_search_post_without_preload_content(
        self,
        request: Annotated[DtoUserSearchRequest, Field(description="User search request")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search users

        Search users with complex filtering and sorting

        :param request: User search request (required)
        :type request: DtoUserSearchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v2_users_search_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoSearchResponseDtoUserResponse",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v2_users_search_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/users/search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictBytes, StrictStr, field_validator
from typing import List, Optional, Tuple, Union
from typing_extensions import Annotated
from rcabench.openapi.models.dto_generic_response_dto_submit_resp import DtoGenericResponseDtoSubmitResp

from rcabench.openapi.api_client import ApiClient, RequestSerialized
from rcabench.openapi.api_response import ApiResponse
from rcabench.openapi.rest import RESTResponseType


class ContainerApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://rcabench.openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_containers_post(
        self,
        image: Annotated[StrictStr, Field(description="Docker镜像名称。当source_type为harbor时，指定Harbor中已存在的镜像名称；其他情况下支持以下格式：1) image-name（自动添加默认Harbor地址和命名空间）2) namespace/image-name（自动添加默认Harbor地址）")],
        type: Annotated[Optional[StrictStr], Field(description="容器类型，指定容器的用途")] = None,
        name: Annotated[Optional[StrictStr], Field(description="容器名称，用于标识容器，将作为镜像构建的标识符，默认使用info.toml中的name字段")] = None,
        tag: Annotated[Optional[StrictStr], Field(description="Docker镜像标签。当source_type为harbor时，指定Harbor中已存在的镜像标签；其他情况下用于版本控制")] = None,
        command: Annotated[Optional[StrictStr], Field(description="Docker镜像启动命令，默认为bash /entrypoint.sh")] = None,
        env_vars: Annotated[Optional[List[StrictStr]], Field(description="环境变量名称列表，支持多个环境变量")] = None,
        source_type: Annotated[Optional[StrictStr], Field(description="构建源类型，指定源码来源")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="源码文件（支持zip或tar.gz格式），当source_type为file时必需，文件大小限制5MB")] = None,
        github_token: Annotated[Optional[StrictStr], Field(description="GitHub访问令牌，用于访问私有仓库，公开仓库可不提供")] = None,
        github_repo: Annotated[Optional[StrictStr], Field(description="GitHub仓库地址，格式：owner/repo，当source_type为github时必需")] = None,
        github_branch: Annotated[Optional[StrictStr], Field(description="GitHub分支名，指定要构建的分支")] = None,
        github_commit: Annotated[Optional[StrictStr], Field(description="GitHub commit哈希值（支持短hash），如果指定commit则忽略branch参数")] = None,
        github_path: Annotated[Optional[StrictStr], Field(description="仓库内的子目录路径，如果源码不在根目录")] = None,
        context_dir: Annotated[Optional[StrictStr], Field(description="Docker构建上下文路径，相对于源码根目录")] = None,
        dockerfile_path: Annotated[Optional[StrictStr], Field(description="Dockerfile路径，相对于源码根目录")] = None,
        target: Annotated[Optional[StrictStr], Field(description="Dockerfile构建目标（multi-stage build时使用）")] = None,
        force_rebuild: Annotated[Optional[StrictBool], Field(description="是否强制重新构建镜像，忽略缓存")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoSubmitResp:
        """提交镜像构建任务

        通过上传文件、指定GitHub仓库或Harbor镜像来构建Docker镜像。支持zip和tar.gz格式的文件上传，或从GitHub仓库自动拉取代码进行构建，或从Harbor直接获取已存在的镜像并更新数据库。系统会自动验证必需文件（Dockerfile）并设置执行权限

        :param image: Docker镜像名称。当source_type为harbor时，指定Harbor中已存在的镜像名称；其他情况下支持以下格式：1) image-name（自动添加默认Harbor地址和命名空间）2) namespace/image-name（自动添加默认Harbor地址） (required)
        :type image: str
        :param type: 容器类型，指定容器的用途
        :type type: str
        :param name: 容器名称，用于标识容器，将作为镜像构建的标识符，默认使用info.toml中的name字段
        :type name: str
        :param tag: Docker镜像标签。当source_type为harbor时，指定Harbor中已存在的镜像标签；其他情况下用于版本控制
        :type tag: str
        :param command: Docker镜像启动命令，默认为bash /entrypoint.sh
        :type command: str
        :param env_vars: 环境变量名称列表，支持多个环境变量
        :type env_vars: List[str]
        :param source_type: 构建源类型，指定源码来源
        :type source_type: str
        :param file: 源码文件（支持zip或tar.gz格式），当source_type为file时必需，文件大小限制5MB
        :type file: bytearray
        :param github_token: GitHub访问令牌，用于访问私有仓库，公开仓库可不提供
        :type github_token: str
        :param github_repo: GitHub仓库地址，格式：owner/repo，当source_type为github时必需
        :type github_repo: str
        :param github_branch: GitHub分支名，指定要构建的分支
        :type github_branch: str
        :param github_commit: GitHub commit哈希值（支持短hash），如果指定commit则忽略branch参数
        :type github_commit: str
        :param github_path: 仓库内的子目录路径，如果源码不在根目录
        :type github_path: str
        :param context_dir: Docker构建上下文路径，相对于源码根目录
        :type context_dir: str
        :param dockerfile_path: Dockerfile路径，相对于源码根目录
        :type dockerfile_path: str
        :param target: Dockerfile构建目标（multi-stage build时使用）
        :type target: str
        :param force_rebuild: 是否强制重新构建镜像，忽略缓存
        :type force_rebuild: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_containers_post_serialize(
            image=image,
            type=type,
            name=name,
            tag=tag,
            command=command,
            env_vars=env_vars,
            source_type=source_type,
            file=file,
            github_token=github_token,
            github_repo=github_repo,
            github_branch=github_branch,
            github_commit=github_commit,
            github_path=github_path,
            context_dir=context_dir,
            dockerfile_path=dockerfile_path,
            target=target,
            force_rebuild=force_rebuild,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DtoGenericResponseDtoSubmitResp",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_containers_post_with_http_info(
        self,
        image: Annotated[StrictStr, Field(description="Docker镜像名称。当source_type为harbor时，指定Harbor中已存在的镜像名称；其他情况下支持以下格式：1) image-name（自动添加默认Harbor地址和命名空间）2) namespace/image-name（自动添加默认Harbor地址）")],
        type: Annotated[Optional[StrictStr], Field(description="容器类型，指定容器的用途")] = None,
        name: Annotated[Optional[StrictStr], Field(description="容器名称，用于标识容器，将作为镜像构建的标识符，默认使用info.toml中的name字段")] = None,
        tag: Annotated[Optional[StrictStr], Field(description="Docker镜像标签。当source_type为harbor时，指定Harbor中已存在的镜像标签；其他情况下用于版本控制")] = None,
        command: Annotated[Optional[StrictStr], Field(description="Docker镜像启动命令，默认为bash /entrypoint.sh")] = None,
        env_vars: Annotated[Optional[List[StrictStr]], Field(description="环境变量名称列表，支持多个环境变量")] = None,
        source_type: Annotated[Optional[StrictStr], Field(description="构建源类型，指定源码来源")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="源码文件（支持zip或tar.gz格式），当source_type为file时必需，文件大小限制5MB")] = None,
        github_token: Annotated[Optional[StrictStr], Field(description="GitHub访问令牌，用于访问私有仓库，公开仓库可不提供")] = None,
        github_repo: Annotated[Optional[StrictStr], Field(description="GitHub仓库地址，格式：owner/repo，当source_type为github时必需")] = None,
        github_branch: Annotated[Optional[StrictStr], Field(description="GitHub分支名，指定要构建的分支")] = None,
        github_commit: Annotated[Optional[StrictStr], Field(description="GitHub commit哈希值（支持短hash），如果指定commit则忽略branch参数")] = None,
        github_path: Annotated[Optional[StrictStr], Field(description="仓库内的子目录路径，如果源码不在根目录")] = None,
        context_dir: Annotated[Optional[StrictStr], Field(description="Docker构建上下文路径，相对于源码根目录")] = None,
        dockerfile_path: Annotated[Optional[StrictStr], Field(description="Dockerfile路径，相对于源码根目录")] = None,
        target: Annotated[Optional[StrictStr], Field(description="Dockerfile构建目标（multi-stage build时使用）")] = None,
        force_rebuild: Annotated[Optional[StrictBool], Field(description="是否强制重新构建镜像，忽略缓存")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoSubmitResp]:
        """提交镜像构建任务

        通过上传文件、指定GitHub仓库或Harbor镜像来构建Docker镜像。支持zip和tar.gz格式的文件上传，或从GitHub仓库自动拉取代码进行构建，或从Harbor直接获取已存在的镜像并更新数据库。系统会自动验证必需文件（Dockerfile）并设置执行权限

        :param image: Docker镜像名称。当source_type为harbor时，指定Harbor中已存在的镜像名称；其他情况下支持以下格式：1) image-name（自动添加默认Harbor地址和命名空间）2) namespace/image-name（自动添加默认Harbor地址） (required)
        :type image: str
        :param type: 容器类型，指定容器的用途
        :type type: str
        :param name: 容器名称，用于标识容器，将作为镜像构建的标识符，默认使用info.toml中的name字段
        :type name: str
        :param tag: Docker镜像标签。当source_type为harbor时，指定Harbor中已存在的镜像标签；其他情况下用于版本控制
        :type tag: str
        :param command: Docker镜像启动命令，默认为bash /entrypoint.sh
        :type command: str
        :param env_vars: 环境变量名称列表，支持多个环境变量
        :type env_vars: List[str]
        :param source_type: 构建源类型，指定源码来源
        :type source_type: str
        :param file: 源码文件（支持zip或tar.gz格式），当source_type为file时必需，文件大小限制5MB
        :type file: bytearray
        :param github_token: GitHub访问令牌，用于访问私有仓库，公开仓库可不提供
        :type github_token: str
        :param github_repo: GitHub仓库地址，格式：owner/repo，当source_type为github时必需
        :type github_repo: str
        :param github_branch: GitHub分支名，指定要构建的分支
        :type github_branch: str
        :param github_commit: GitHub commit哈希值（支持短hash），如果指定commit则忽略branch参数
        :type github_commit: str
        :param github_path: 仓库内的子目录路径，如果源码不在根目录
        :type github_path: str
        :param context_dir: Docker构建上下文路径，相对于源码根目录
        :type context_dir: str
        :param dockerfile_path: Dockerfile路径，相对于源码根目录
        :type dockerfile_path: str
        :param target: Dockerfile构建目标（multi-stage build时使用）
        :type target: str
        :param force_rebuild: 是否强制重新构建镜像，忽略缓存
        :type force_rebuild: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_containers_post_serialize(
            image=image,
            type=type,
            name=name,
            tag=tag,
            command=command,
            env_vars=env_vars,
            source_type=source_type,
            file=file,
            github_token=github_token,
            github_repo=github_repo,
            github_branch=github_branch,
            github_commit=github_commit,
            github_path=github_path,
            context_dir=context_dir,
            dockerfile_path=dockerfile_path,
            target=target,
            force_rebuild=force_rebuild,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DtoGenericResponseDtoSubmitResp",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_containers_post_without_preload_content(
        self,
        image: Annotated[StrictStr, Field(description="Docker镜像名称。当source_type为harbor时，指定Harbor中已存在的镜像名称；其他情况下支持以下格式：1) image-name（自动添加默认Harbor地址和命名空间）2) namespace/image-name（自动添加默认Harbor地址）")],
        type: Annotated[Optional[StrictStr], Field(description="容器类型，指定容器的用途")] = None,
        name: Annotated[Optional[StrictStr], Field(description="容器名称，用于标识容器，将作为镜像构建的标识符，默认使用info.toml中的name字段")] = None,
        tag: Annotated[Optional[StrictStr], Field(description="Docker镜像标签。当source_type为harbor时，指定Harbor中已存在的镜像标签；其他情况下用于版本控制")] = None,
        command: Annotated[Optional[StrictStr], Field(description="Docker镜像启动命令，默认为bash /entrypoint.sh")] = None,
        env_vars: Annotated[Optional[List[StrictStr]], Field(description="环境变量名称列表，支持多个环境变量")] = None,
        source_type: Annotated[Optional[StrictStr], Field(description="构建源类型，指定源码来源")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="源码文件（支持zip或tar.gz格式），当source_type为file时必需，文件大小限制5MB")] = None,
        github_token: Annotated[Optional[StrictStr], Field(description="GitHub访问令牌，用于访问私有仓库，公开仓库可不提供")] = None,
        github_repo: Annotated[Optional[StrictStr], Field(description="GitHub仓库地址，格式：owner/repo，当source_type为github时必需")] = None,
        github_branch: Annotated[Optional[StrictStr], Field(description="GitHub分支名，指定要构建的分支")] = None,
        github_commit: Annotated[Optional[StrictStr], Field(description="GitHub commit哈希值（支持短hash），如果指定commit则忽略branch参数")] = None,
        github_path: Annotated[Optional[StrictStr], Field(description="仓库内的子目录路径，如果源码不在根目录")] = None,
        context_dir: Annotated[Optional[StrictStr], Field(description="Docker构建上下文路径，相对于源码根目录")] = None,
        dockerfile_path: Annotated[Optional[StrictStr], Field(description="Dockerfile路径，相对于源码根目录")] = None,
        target: Annotated[Optional[StrictStr], Field(description="Dockerfile构建目标（multi-stage build时使用）")] = None,
        force_rebuild: Annotated[Optional[StrictBool], Field(description="是否强制重新构建镜像，忽略缓存")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """提交镜像构建任务

        通过上传文件、指定GitHub仓库或Harbor镜像来构建Docker镜像。支持zip和tar.gz格式的文件上传，或从GitHub仓库自动拉取代码进行构建，或从Harbor直接获取已存在的镜像并更新数据库。系统会自动验证必需文件（Dockerfile）并设置执行权限

        :param image: Docker镜像名称。当source_type为harbor时，指定Harbor中已存在的镜像名称；其他情况下支持以下格式：1) image-name（自动添加默认Harbor地址和命名空间）2) namespace/image-name（自动添加默认Harbor地址） (required)
        :type image: str
        :param type: 容器类型，指定容器的用途
        :type type: str
        :param name: 容器名称，用于标识容器，将作为镜像构建的标识符，默认使用info.toml中的name字段
        :type name: str
        :param tag: Docker镜像标签。当source_type为harbor时，指定Harbor中已存在的镜像标签；其他情况下用于版本控制
        :type tag: str
        :param command: Docker镜像启动命令，默认为bash /entrypoint.sh
        :type command: str
        :param env_vars: 环境变量名称列表，支持多个环境变量
        :type env_vars: List[str]
        :param source_type: 构建源类型，指定源码来源
        :type source_type: str
        :param file: 源码文件（支持zip或tar.gz格式），当source_type为file时必需，文件大小限制5MB
        :type file: bytearray
        :param github_token: GitHub访问令牌，用于访问私有仓库，公开仓库可不提供
        :type github_token: str
        :param github_repo: GitHub仓库地址，格式：owner/repo，当source_type为github时必需
        :type github_repo: str
        :param github_branch: GitHub分支名，指定要构建的分支
        :type github_branch: str
        :param github_commit: GitHub commit哈希值（支持短hash），如果指定commit则忽略branch参数
        :type github_commit: str
        :param github_path: 仓库内的子目录路径，如果源码不在根目录
        :type github_path: str
        :param context_dir: Docker构建上下文路径，相对于源码根目录
        :type context_dir: str
        :param dockerfile_path: Dockerfile路径，相对于源码根目录
        :type dockerfile_path: str
        :param target: Dockerfile构建目标（multi-stage build时使用）
        :type target: str
        :param force_rebuild: 是否强制重新构建镜像，忽略缓存
        :type force_rebuild: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_containers_post_serialize(
            image=image,
            type=type,
            name=name,
            tag=tag,
            command=command,
            env_vars=env_vars,
            source_type=source_type,
            file=file,
            github_token=github_token,
            github_repo=github_repo,
            github_branch=github_branch,
            github_commit=github_commit,
            github_path=github_path,
            context_dir=context_dir,
            dockerfile_path=dockerfile_path,
            target=target,
            force_rebuild=force_rebuild,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DtoGenericResponseDtoSubmitResp",
            '400': "DtoGenericResponseAny",
            '404': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_containers_post_serialize(
        self,
        image,
        type,
        name,
        tag,
        command,
        env_vars,
        source_type,
        file,
        github_token,
        github_repo,
        github_branch,
        github_commit,
        github_path,
        context_dir,
        dockerfile_path,
        target,
        force_rebuild,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'env_vars': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        if type is not None:
            _form_params.append(('type', type))
        if name is not None:
            _form_params.append(('name', name))
        if image is not None:
            _form_params.append(('image', image))
        if tag is not None:
            _form_params.append(('tag', tag))
        if command is not None:
            _form_params.append(('command', command))
        if env_vars is not None:
            _form_params.append(('env_vars', env_vars))
        if source_type is not None:
            _form_params.append(('source_type', source_type))
        if file is not None:
            _files['file'] = file
        if github_token is not None:
            _form_params.append(('github_token', github_token))
        if github_repo is not None:
            _form_params.append(('github_repo', github_repo))
        if github_branch is not None:
            _form_params.append(('github_branch', github_branch))
        if github_commit is not None:
            _form_params.append(('github_commit', github_commit))
        if github_path is not None:
            _form_params.append(('github_path', github_path))
        if context_dir is not None:
            _form_params.append(('context_dir', context_dir))
        if dockerfile_path is not None:
            _form_params.append(('dockerfile_path', dockerfile_path))
        if target is not None:
            _form_params.append(('target', target))
        if force_rebuild is not None:
            _form_params.append(('force_rebuild', force_rebuild))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/containers',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AlgorithmsApi",
    "AuthenticationApi",
    "ContainersApi",
    "DatasetsApi",
    "PermissionsApi",
    "RelationsApi",
    "RolesApi",
    "SystemApi",
    "TasksApi",
    "UsersApi",
    "AlgorithmApi",
    "AnalyzerApi",
    "ContainerApi",
    "DatasetApi",
    "DebugApi",
    "EvaluationApi",
    "InjectionApi",
    "TaskApi",
    "TraceApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ConstsTaskType",
    "DatabaseContainer",
    "DatabaseFaultInjectionSchedule",
    "DatabaseLabel",
    "DatabaseProject",
    "DatabaseTask",
    "DatabaseUser",
    "DtoAdvancedSearchRequest",
    "DtoAlgorithmDatasetPair",
    "DtoAlgorithmItem",
    "DtoAlgorithmResponse",
    "DtoAlgorithmSearchRequest",
    "DtoAnalyzeInjectionsResp",
    "DtoAssignUserPermissionRequest",
    "DtoAssignUserRoleRequest",
    "DtoAssignUserToProjectRequest",
    "DtoAttributeCoverageItem",
    "DtoAuditLogListResponse",
    "DtoAuditLogRequest",
    "DtoAuditLogResponse",
    "DtoBatchRelationRequest",
    "DtoChangePasswordRequest",
    "DtoContainerResponse",
    "DtoContainerSearchRequest",
    "DtoContainerStatistics",
    "DtoCreatePermissionRequest",
    "DtoCreateRoleRequest",
    "DtoCreateUserRequest",
    "DtoDatasetBuildPayload",
    "DtoDatasetDeleteResp",
    "DtoDatasetSearchResponse",
    "DtoDatasetStatistics",
    "DtoDatasetV2CreateReq",
    "DtoDatasetV2InjectionManageReq",
    "DtoDatasetV2InjectionRelationResponse",
    "DtoDatasetV2LabelCreateReq",
    "DtoDatasetV2LabelManageReq",
    "DtoDatasetV2Response",
    "DtoDatasetV2SearchReq",
    "DtoDatasetV2UpdateReq",
    "DtoDateRange",
    "DtoDateRangeFilter",
    "DtoExecutionPayload",
    "DtoExecutionStatistics",
    "DtoFaultInjectionNoIssuesResp",
    "DtoFaultInjectionWithIssuesResp",
    "DtoFilterOperator",
    "DtoGenericResponseAny",
    "DtoGenericResponseArrayDtoFaultInjectionNoIssuesResp",
    "DtoGenericResponseArrayDtoFaultInjectionWithIssuesResp",
    "DtoGenericResponseArrayDtoPermissionResponse",
    "DtoGenericResponseArrayDtoRoleResponse",
    "DtoGenericResponseArrayDtoUserResponse",
    "DtoGenericResponseDtoAnalyzeInjectionsResp",
    "DtoGenericResponseDtoAuditLogListResponse",
    "DtoGenericResponseDtoAuditLogResponse",
    "DtoGenericResponseDtoContainerResponse",
    "DtoGenericResponseDtoDatasetDeleteResp",
    "DtoGenericResponseDtoDatasetSearchResponse",
    "DtoGenericResponseDtoDatasetV2Response",
    "DtoGenericResponseDtoGetCompletedMapResp",
    "DtoGenericResponseDtoGroundTruthResp",
    "DtoGenericResponseDtoHealthCheckResponse",
    "DtoGenericResponseDtoInjectCancelResp",
    "DtoGenericResponseDtoInjectionFieldMappingResp",
    "DtoGenericResponseDtoInjectionStatsResp",
    "DtoGenericResponseDtoListAlgorithmsResp",
    "DtoGenericResponseDtoListInjectionsResp",
    "DtoGenericResponseDtoListTasksResp",
    "DtoGenericResponseDtoLoginResponse",
    "DtoGenericResponseDtoMonitoringMetricsResponse",
    "DtoGenericResponseDtoNsResourcesResp",
    "DtoGenericResponseDtoPaginationRespDtoUnifiedTask",
    "DtoGenericResponseDtoPermissionListResponse",
    "DtoGenericResponseDtoPermissionResponse",
    "DtoGenericResponseDtoQueryInjectionResp",
    "DtoGenericResponseDtoRawDataResp",
    "DtoGenericResponseDtoRelationListResponse",
    "DtoGenericResponseDtoRelationStatisticsResponse",
    "DtoGenericResponseDtoRoleListResponse",
    "DtoGenericResponseDtoRoleResponse",
    "DtoGenericResponseDtoSearchResponseDtoAlgorithmResponse",
    "DtoGenericResponseDtoSearchResponseDtoContainerResponse",
    "DtoGenericResponseDtoSearchResponseDtoDatasetV2Response",
    "DtoGenericResponseDtoSearchResponseDtoPermissionResponse",
    "DtoGenericResponseDtoSearchResponseDtoRoleResponse",
    "DtoGenericResponseDtoSearchResponseDtoTaskResponse",
    "DtoGenericResponseDtoSearchResponseDtoUserResponse",
    "DtoGenericResponseDtoSubmitInjectionResp",
    "DtoGenericResponseDtoSubmitResp",
    "DtoGenericResponseDtoSuccessfulExecutionsResp",
    "DtoGenericResponseDtoSystemInfo",
    "DtoGenericResponseDtoSystemStatisticsResponse",
    "DtoGenericResponseDtoTaskDetailResp",
    "DtoGenericResponseDtoTaskDetailResponse",
    "DtoGenericResponseDtoTokenRefreshResponse",
    "DtoGenericResponseDtoTraceStats",
    "DtoGenericResponseDtoUserInfo",
    "DtoGenericResponseDtoUserListResponse",
    "DtoGenericResponseDtoUserResponse",
    "DtoGenericResponseHandlerNode",
    "DtoGenericResponseHandlerResources",
    "DtoGetCompletedMapResp",
    "DtoGranularityRecord",
    "DtoGroundTruthReq",
    "DtoHealthCheckResponse",
    "DtoInjectionDiversity",
    "DtoInjectionFieldMappingResp",
    "DtoInjectionItem",
    "DtoInjectionStatistics",
    "DtoInjectionStats",
    "DtoInjectionStatsResp",
    "DtoLabelItem",
    "DtoListInjectionsResp",
    "DtoLoginRequest",
    "DtoLoginResponse",
    "DtoLogoutRequest",
    "DtoMetricValue",
    "DtoMonitoringMetricsResponse",
    "DtoMonitoringQueryRequest",
    "DtoNumberRange",
    "DtoPaginationInfo",
    "DtoPaginationRespDtoUnifiedTask",
    "DtoPairStats",
    "DtoPermissionListResponse",
    "DtoPermissionResponse",
    "DtoPermissionSearchRequest",
    "DtoProjectResponse",
    "DtoProjectStatistics",
    "DtoQueryInjectionResp",
    "DtoRawDataItem",
    "DtoRawDataReq",
    "DtoRegisterRequest",
    "DtoRelationEntity",
    "DtoRelationListResponse",
    "DtoRelationOperation",
    "DtoRelationResponse",
    "DtoRelationStatisticsResponse",
    "DtoRemoveUserPermissionRequest",
    "DtoRemoveUserRoleRequest",
    "DtoResourceResponse",
    "DtoRetryPolicy",
    "DtoRoleListResponse",
    "DtoRoleResponse",
    "DtoRoleSearchRequest",
    "DtoSearchFilter",
    "DtoSearchResponseDtoAlgorithmResponse",
    "DtoSearchResponseDtoContainerResponse",
    "DtoSearchResponseDtoDatasetV2Response",
    "DtoSearchResponseDtoPermissionResponse",
    "DtoSearchResponseDtoRoleResponse",
    "DtoSearchResponseDtoTaskResponse",
    "DtoSearchResponseDtoUserResponse",
    "DtoServiceCoverageItem",
    "DtoServiceInfo",
    "DtoSizeRangeFilter",
    "DtoSortDirection",
    "DtoSortOption",
    "DtoSubmitDatasetBuildingReq",
    "DtoSubmitExecutionReq",
    "DtoSubmitInjectionReq",
    "DtoSubmitInjectionResp",
    "DtoSubmitResp",
    "DtoSuccessfulExecutionItem",
    "DtoSystemInfo",
    "DtoSystemStatisticsResponse",
    "DtoTaskDetailResp",
    "DtoTaskDetailResponse",
    "DtoTaskItem",
    "DtoTaskResponse",
    "DtoTaskSearchRequest",
    "DtoTaskStatistics",
    "DtoTokenRefreshRequest",
    "DtoTokenRefreshResponse",
    "DtoTrace",
    "DtoTraceStats",
    "DtoUnifiedTask",
    "DtoUpdateContainerRequest",
    "DtoUpdatePermissionRequest",
    "DtoUpdateRoleRequest",
    "DtoUpdateUserRequest",
    "DtoUserInfo",
    "DtoUserListResponse",
    "DtoUserProjectResponse",
    "DtoUserResponse",
    "DtoUserSearchRequest",
    "DtoUserStatistics",
    "HandlerGroundtruth",
    "HandlerNode",
    "HandlerPair",
    "HandlerResources",
]

# import apis into sdk package
from rcabench.openapi.api.algorithms_api import AlgorithmsApi as AlgorithmsApi
from rcabench.openapi.api.authentication_api import AuthenticationApi as AuthenticationApi
from rcabench.openapi.api.containers_api import ContainersApi as ContainersApi
from rcabench.openapi.api.datasets_api import DatasetsApi as DatasetsApi
from rcabench.openapi.api.permissions_api import PermissionsApi as PermissionsApi
from rcabench.openapi.api.relations_api import RelationsApi as RelationsApi
from rcabench.openapi.api.roles_api import RolesApi as RolesApi
from rcabench.openapi.api.system_api import SystemApi as SystemApi
from rcabench.openapi.api.tasks_api import TasksApi as TasksApi
from rcabench.openapi.api.users_api import UsersApi as UsersApi
from rcabench.openapi.api.algorithm_api import AlgorithmApi as AlgorithmApi
from rcabench.openapi.api.analyzer_api import AnalyzerApi as AnalyzerApi
from rcabench.openapi.api.container_api import ContainerApi as ContainerApi
from rcabench.openapi.api.dataset_api import DatasetApi as DatasetApi
from rcabench.openapi.api.debug_api import DebugApi as DebugApi
from rcabench.openapi.api.evaluation_api import EvaluationApi as EvaluationApi
from rcabench.openapi.api.injection_api import InjectionApi as InjectionApi
from rcabench.openapi.api.task_api import TaskApi as TaskApi
from rcabench.openapi.api.trace_api import TraceApi as TraceApi

# import ApiClient
from rcabench.openapi.api_response import ApiResponse as ApiResponse
from rcabench.openapi.api_client import ApiClient as ApiClient
from rcabench.openapi.configuration import Configuration as Configuration
from rcabench.openapi.exceptions import OpenApiException as OpenApiException
from rcabench.openapi.exceptions import ApiTypeError as ApiTypeError
from rcabench.openapi.exceptions import ApiValueError as ApiValueError
from rcabench.openapi.exceptions import ApiKeyError as ApiKeyError
from rcabench.openapi.exceptions import ApiAttributeError as ApiAttributeError
from rcabench.openapi.exceptions import ApiException as ApiException

# import models into sdk package
from rcabench.openapi.models.consts_task_type import ConstsTaskType as ConstsTaskType
from rcabench.openapi.models.database_container import DatabaseContainer as DatabaseContainer
from rcabench.openapi.models.database_fault_injection_schedule import DatabaseFaultInjectionSchedule as DatabaseFaultInjectionSchedule
from rcabench.openapi.models.database_label import DatabaseLabel as DatabaseLabel
from rcabench.openapi.models.database_project import DatabaseProject as DatabaseProject
from rcabench.openapi.models.database_task import DatabaseTask as DatabaseTask
from rcabench.openapi.models.database_user import DatabaseUser as DatabaseUser
from rcabench.openapi.models.dto_advanced_search_request import DtoAdvancedSearchRequest as DtoAdvancedSearchRequest
from rcabench.openapi.models.dto_algorithm_dataset_pair import DtoAlgorithmDatasetPair as DtoAlgorithmDatasetPair
from rcabench.openapi.models.dto_algorithm_item import DtoAlgorithmItem as DtoAlgorithmItem
from rcabench.openapi.models.dto_algorithm_response import DtoAlgorithmResponse as DtoAlgorithmResponse
from rcabench.openapi.models.dto_algorithm_search_request import DtoAlgorithmSearchRequest as DtoAlgorithmSearchRequest
from rcabench.openapi.models.dto_analyze_injections_resp import DtoAnalyzeInjectionsResp as DtoAnalyzeInjectionsResp
from rcabench.openapi.models.dto_assign_user_permission_request import DtoAssignUserPermissionRequest as DtoAssignUserPermissionRequest
from rcabench.openapi.models.dto_assign_user_role_request import DtoAssignUserRoleRequest as DtoAssignUserRoleRequest
from rcabench.openapi.models.dto_assign_user_to_project_request import DtoAssignUserToProjectRequest as DtoAssignUserToProjectRequest
from rcabench.openapi.models.dto_attribute_coverage_item import DtoAttributeCoverageItem as DtoAttributeCoverageItem
from rcabench.openapi.models.dto_audit_log_list_response import DtoAuditLogListResponse as DtoAuditLogListResponse
from rcabench.openapi.models.dto_audit_log_request import DtoAuditLogRequest as DtoAuditLogRequest
from rcabench.openapi.models.dto_audit_log_response import DtoAuditLogResponse as DtoAuditLogResponse
from rcabench.openapi.models.dto_batch_relation_request import DtoBatchRelationRequest as DtoBatchRelationRequest
from rcabench.openapi.models.dto_change_password_request import DtoChangePasswordRequest as DtoChangePasswordRequest
from rcabench.openapi.models.dto_container_response import DtoContainerResponse as DtoContainerResponse
from rcabench.openapi.models.dto_container_search_request import DtoContainerSearchRequest as DtoContainerSearchRequest
from rcabench.openapi.models.dto_container_statistics import DtoContainerStatistics as DtoContainerStatistics
from rcabench.openapi.models.dto_create_permission_request import DtoCreatePermissionRequest as DtoCreatePermissionRequest
from rcabench.openapi.models.dto_create_role_request import DtoCreateRoleRequest as DtoCreateRoleRequest
from rcabench.openapi.models.dto_create_user_request import DtoCreateUserRequest as DtoCreateUserRequest
from rcabench.openapi.models.dto_dataset_build_payload import DtoDatasetBuildPayload as DtoDatasetBuildPayload
from rcabench.openapi.models.dto_dataset_delete_resp import DtoDatasetDeleteResp as DtoDatasetDeleteResp
from rcabench.openapi.models.dto_dataset_search_response import DtoDatasetSearchResponse as DtoDatasetSearchResponse
from rcabench.openapi.models.dto_dataset_statistics import DtoDatasetStatistics as DtoDatasetStatistics
from rcabench.openapi.models.dto_dataset_v2_create_req import DtoDatasetV2CreateReq as DtoDatasetV2CreateReq
from rcabench.openapi.models.dto_dataset_v2_injection_manage_req import DtoDatasetV2InjectionManageReq as DtoDatasetV2InjectionManageReq
from rcabench.openapi.models.dto_dataset_v2_injection_relation_response import DtoDatasetV2InjectionRelationResponse as DtoDatasetV2InjectionRelationResponse
from rcabench.openapi.models.dto_dataset_v2_label_create_req import DtoDatasetV2LabelCreateReq as DtoDatasetV2LabelCreateReq
from rcabench.openapi.models.dto_dataset_v2_label_manage_req import DtoDatasetV2LabelManageReq as DtoDatasetV2LabelManageReq
from rcabench.openapi.models.dto_dataset_v2_response import DtoDatasetV2Response as DtoDatasetV2Response
from rcabench.openapi.models.dto_dataset_v2_search_req import DtoDatasetV2SearchReq as DtoDatasetV2SearchReq
from rcabench.openapi.models.dto_dataset_v2_update_req import DtoDatasetV2UpdateReq as DtoDatasetV2UpdateReq
from rcabench.openapi.models.dto_date_range import DtoDateRange as DtoDateRange
from rcabench.openapi.models.dto_date_range_filter import DtoDateRangeFilter as DtoDateRangeFilter
from rcabench.openapi.models.dto_execution_payload import DtoExecutionPayload as DtoExecutionPayload
from rcabench.openapi.models.dto_execution_statistics import DtoExecutionStatistics as DtoExecutionStatistics
from rcabench.openapi.models.dto_fault_injection_no_issues_resp import DtoFaultInjectionNoIssuesResp as DtoFaultInjectionNoIssuesResp
from rcabench.openapi.models.dto_fault_injection_with_issues_resp import DtoFaultInjectionWithIssuesResp as DtoFaultInjectionWithIssuesResp
from rcabench.openapi.models.dto_filter_operator import DtoFilterOperator as DtoFilterOperator
from rcabench.openapi.models.dto_generic_response_any import DtoGenericResponseAny as DtoGenericResponseAny
from rcabench.openapi.models.dto_generic_response_array_dto_fault_injection_no_issues_resp import DtoGenericResponseArrayDtoFaultInjectionNoIssuesResp as DtoGenericResponseArrayDtoFaultInjectionNoIssuesResp
from rcabench.openapi.models.dto_generic_response_array_dto_fault_injection_with_issues_resp import DtoGenericResponseArrayDtoFaultInjectionWithIssuesResp as DtoGenericResponseArrayDtoFaultInjectionWithIssuesResp
from rcabench.openapi.models.dto_generic_response_array_dto_permission_response import DtoGenericResponseArrayDtoPermissionResponse as DtoGenericResponseArrayDtoPermissionResponse
from rcabench.openapi.models.dto_generic_response_array_dto_role_response import DtoGenericResponseArrayDtoRoleResponse as DtoGenericResponseArrayDtoRoleResponse
from rcabench.openapi.models.dto_generic_response_array_dto_user_response import DtoGenericResponseArrayDtoUserResponse as DtoGenericResponseArrayDtoUserResponse
from rcabench.openapi.models.dto_generic_response_dto_analyze_injections_resp import DtoGenericResponseDtoAnalyzeInjectionsResp as DtoGenericResponseDtoAnalyzeInjectionsResp
from rcabench.openapi.models.dto_generic_response_dto_audit_log_list_response import DtoGenericResponseDtoAuditLogListResponse as DtoGenericResponseDtoAuditLogListResponse
from rcabench.openapi.models.dto_generic_response_dto_audit_log_response import DtoGenericResponseDtoAuditLogResponse as DtoGenericResponseDtoAuditLogResponse
from rcabench.openapi.models.dto_generic_response_dto_container_response import DtoGenericResponseDtoContainerResponse as DtoGenericResponseDtoContainerResponse
from rcabench.openapi.models.dto_generic_response_dto_dataset_delete_resp import DtoGenericResponseDtoDatasetDeleteResp as DtoGenericResponseDtoDatasetDeleteResp
from rcabench.openapi.models.dto_generic_response_dto_dataset_search_response import DtoGenericResponseDtoDatasetSearchResponse as DtoGenericResponseDtoDatasetSearchResponse
from rcabench.openapi.models.dto_generic_response_dto_dataset_v2_response import DtoGenericResponseDtoDatasetV2Response as DtoGenericResponseDtoDatasetV2Response
from rcabench.openapi.models.dto_generic_response_dto_get_completed_map_resp import DtoGenericResponseDtoGetCompletedMapResp as DtoGenericResponseDtoGetCompletedMapResp
from rcabench.openapi.models.dto_generic_response_dto_ground_truth_resp import DtoGenericResponseDtoGroundTruthResp as DtoGenericResponseDtoGroundTruthResp
from rcabench.openapi.models.dto_generic_response_dto_health_check_response import DtoGenericResponseDtoHealthCheckResponse as DtoGenericResponseDtoHealthCheckResponse
from rcabench.openapi.models.dto_generic_response_dto_inject_cancel_resp import DtoGenericResponseDtoInjectCancelResp as DtoGenericResponseDtoInjectCancelResp
from rcabench.openapi.models.dto_generic_response_dto_injection_field_mapping_resp import DtoGenericResponseDtoInjectionFieldMappingResp as DtoGenericResponseDtoInjectionFieldMappingResp
from rcabench.openapi.models.dto_generic_response_dto_injection_stats_resp import DtoGenericResponseDtoInjectionStatsResp as DtoGenericResponseDtoInjectionStatsResp
from rcabench.openapi.models.dto_generic_response_dto_list_algorithms_resp import DtoGenericResponseDtoListAlgorithmsResp as DtoGenericResponseDtoListAlgorithmsResp
from rcabench.openapi.models.dto_generic_response_dto_list_injections_resp import DtoGenericResponseDtoListInjectionsResp as DtoGenericResponseDtoListInjectionsResp
from rcabench.openapi.models.dto_generic_response_dto_list_tasks_resp import DtoGenericResponseDtoListTasksResp as DtoGenericResponseDtoListTasksResp
from rcabench.openapi.models.dto_generic_response_dto_login_response import DtoGenericResponseDtoLoginResponse as DtoGenericResponseDtoLoginResponse
from rcabench.openapi.models.dto_generic_response_dto_monitoring_metrics_response import DtoGenericResponseDtoMonitoringMetricsResponse as DtoGenericResponseDtoMonitoringMetricsResponse
from rcabench.openapi.models.dto_generic_response_dto_ns_resources_resp import DtoGenericResponseDtoNsResourcesResp as DtoGenericResponseDtoNsResourcesResp
from rcabench.openapi.models.dto_generic_response_dto_pagination_resp_dto_unified_task import DtoGenericResponseDtoPaginationRespDtoUnifiedTask as DtoGenericResponseDtoPaginationRespDtoUnifiedTask
from rcabench.openapi.models.dto_generic_response_dto_permission_list_response import DtoGenericResponseDtoPermissionListResponse as DtoGenericResponseDtoPermissionListResponse
from rcabench.openapi.models.dto_generic_response_dto_permission_response import DtoGenericResponseDtoPermissionResponse as DtoGenericResponseDtoPermissionResponse
from rcabench.openapi.models.dto_generic_response_dto_query_injection_resp import DtoGenericResponseDtoQueryInjectionResp as DtoGenericResponseDtoQueryInjectionResp
from rcabench.openapi.models.dto_generic_response_dto_raw_data_resp import DtoGenericResponseDtoRawDataResp as DtoGenericResponseDtoRawDataResp
from rcabench.openapi.models.dto_generic_response_dto_relation_list_response import DtoGenericResponseDtoRelationListResponse as DtoGenericResponseDtoRelationListResponse
from rcabench.openapi.models.dto_generic_response_dto_relation_statistics_response import DtoGenericResponseDtoRelationStatisticsResponse as DtoGenericResponseDtoRelationStatisticsResponse
from rcabench.openapi.models.dto_generic_response_dto_role_list_response import DtoGenericResponseDtoRoleListResponse as DtoGenericResponseDtoRoleListResponse
from rcabench.openapi.models.dto_generic_response_dto_role_response import DtoGenericResponseDtoRoleResponse as DtoGenericResponseDtoRoleResponse
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_algorithm_response import DtoGenericResponseDtoSearchResponseDtoAlgorithmResponse as DtoGenericResponseDtoSearchResponseDtoAlgorithmResponse
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_container_response import DtoGenericResponseDtoSearchResponseDtoContainerResponse as DtoGenericResponseDtoSearchResponseDtoContainerResponse
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_dataset_v2_response import DtoGenericResponseDtoSearchResponseDtoDatasetV2Response as DtoGenericResponseDtoSearchResponseDtoDatasetV2Response
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_permission_response import DtoGenericResponseDtoSearchResponseDtoPermissionResponse as DtoGenericResponseDtoSearchResponseDtoPermissionResponse
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_role_response import DtoGenericResponseDtoSearchResponseDtoRoleResponse as DtoGenericResponseDtoSearchResponseDtoRoleResponse
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_task_response import DtoGenericResponseDtoSearchResponseDtoTaskResponse as DtoGenericResponseDtoSearchResponseDtoTaskResponse
from rcabench.openapi.models.dto_generic_response_dto_search_response_dto_user_response import DtoGenericResponseDtoSearchResponseDtoUserResponse as DtoGenericResponseDtoSearchResponseDtoUserResponse
from rcabench.openapi.models.dto_generic_response_dto_submit_injection_resp import DtoGenericResponseDtoSubmitInjectionResp as DtoGenericResponseDtoSubmitInjectionResp
from rcabench.openapi.models.dto_generic_response_dto_submit_resp import DtoGenericResponseDtoSubmitResp as DtoGenericResponseDtoSubmitResp
from rcabench.openapi.models.dto_generic_response_dto_successful_executions_resp import DtoGenericResponseDtoSuccessfulExecutionsResp as DtoGenericResponseDtoSuccessfulExecutionsResp
from rcabench.openapi.models.dto_generic_response_dto_system_info import DtoGenericResponseDtoSystemInfo as DtoGenericResponseDtoSystemInfo
from rcabench.openapi.models.dto_generic_response_dto_system_statistics_response import DtoGenericResponseDtoSystemStatisticsResponse as DtoGenericResponseDtoSystemStatisticsResponse
from rcabench.openapi.models.dto_generic_response_dto_task_detail_resp import DtoGenericResponseDtoTaskDetailResp as DtoGenericResponseDtoTaskDetailResp
from rcabench.openapi.models.dto_generic_response_dto_task_detail_response import DtoGenericResponseDtoTaskDetailResponse as DtoGenericResponseDtoTaskDetailResponse
from rcabench.openapi.models.dto_generic_response_dto_token_refresh_response import DtoGenericResponseDtoTokenRefreshResponse as DtoGenericResponseDtoTokenRefreshResponse
from rcabench.openapi.models.dto_generic_response_dto_trace_stats import DtoGenericResponseDtoTraceStats as DtoGenericResponseDtoTraceStats
from rcabench.openapi.models.dto_generic_response_dto_user_info import DtoGenericResponseDtoUserInfo as DtoGenericResponseDtoUserInfo
from rcabench.openapi.models.dto_generic_response_dto_user_list_response import DtoGenericResponseDtoUserListResponse as DtoGenericResponseDtoUserListResponse
from rcabench.openapi.models.dto_generic_response_dto_user_response import DtoGenericResponseDtoUserResponse as DtoGenericResponseDtoUserResponse
from rcabench.openapi.models.dto_generic_response_handler_node import DtoGenericResponseHandlerNode as DtoGenericResponseHandlerNode
from rcabench.openapi.models.dto_generic_response_handler_resources import DtoGenericResponseHandlerResources as DtoGenericResponseHandlerResources
from rcabench.openapi.models.dto_get_completed_map_resp import DtoGetCompletedMapResp as DtoGetCompletedMapResp
from rcabench.openapi.models.dto_granularity_record import DtoGranularityRecord as DtoGranularityRecord
from rcabench.openapi.models.dto_ground_truth_req import DtoGroundTruthReq as DtoGroundTruthReq
from rcabench.openapi.models.dto_health_check_response import DtoHealthCheckResponse as DtoHealthCheckResponse
from rcabench.openapi.models.dto_injection_diversity import DtoInjectionDiversity as DtoInjectionDiversity
from rcabench.openapi.models.dto_injection_field_mapping_resp import DtoInjectionFieldMappingResp as DtoInjectionFieldMappingResp
from rcabench.openapi.models.dto_injection_item import DtoInjectionItem as DtoInjectionItem
from rcabench.openapi.models.dto_injection_statistics import DtoInjectionStatistics as DtoInjectionStatistics
from rcabench.openapi.models.dto_injection_stats import DtoInjectionStats as DtoInjectionStats
from rcabench.openapi.models.dto_injection_stats_resp import DtoInjectionStatsResp as DtoInjectionStatsResp
from rcabench.openapi.models.dto_label_item import DtoLabelItem as DtoLabelItem
from rcabench.openapi.models.dto_list_injections_resp import DtoListInjectionsResp as DtoListInjectionsResp
from rcabench.openapi.models.dto_login_request import DtoLoginRequest as DtoLoginRequest
from rcabench.openapi.models.dto_login_response import DtoLoginResponse as DtoLoginResponse
from rcabench.openapi.models.dto_logout_request import DtoLogoutRequest as DtoLogoutRequest
from rcabench.openapi.models.dto_metric_value import DtoMetricValue as DtoMetricValue
from rcabench.openapi.models.dto_monitoring_metrics_response import DtoMonitoringMetricsResponse as DtoMonitoringMetricsResponse
from rcabench.openapi.models.dto_monitoring_query_request import DtoMonitoringQueryRequest as DtoMonitoringQueryRequest
from rcabench.openapi.models.dto_number_range import DtoNumberRange as DtoNumberRange
from rcabench.openapi.models.dto_pagination_info import DtoPaginationInfo as DtoPaginationInfo
from rcabench.openapi.models.dto_pagination_resp_dto_unified_task import DtoPaginationRespDtoUnifiedTask as DtoPaginationRespDtoUnifiedTask
from rcabench.openapi.models.dto_pair_stats import DtoPairStats as DtoPairStats
from rcabench.openapi.models.dto_permission_list_response import DtoPermissionListResponse as DtoPermissionListResponse
from rcabench.openapi.models.dto_permission_response import DtoPermissionResponse as DtoPermissionResponse
from rcabench.openapi.models.dto_permission_search_request import DtoPermissionSearchRequest as DtoPermissionSearchRequest
from rcabench.openapi.models.dto_project_response import DtoProjectResponse as DtoProjectResponse
from rcabench.openapi.models.dto_project_statistics import DtoProjectStatistics as DtoProjectStatistics
from rcabench.openapi.models.dto_query_injection_resp import DtoQueryInjectionResp as DtoQueryInjectionResp
from rcabench.openapi.models.dto_raw_data_item import DtoRawDataItem as DtoRawDataItem
from rcabench.openapi.models.dto_raw_data_req import DtoRawDataReq as DtoRawDataReq
from rcabench.openapi.models.dto_register_request import DtoRegisterRequest as DtoRegisterRequest
from rcabench.openapi.models.dto_relation_entity import DtoRelationEntity as DtoRelationEntity
from rcabench.openapi.models.dto_relation_list_response import DtoRelationListResponse as DtoRelationListResponse
from rcabench.openapi.models.dto_relation_operation import DtoRelationOperation as DtoRelationOperation
from rcabench.openapi.models.dto_relation_response import DtoRelationResponse as DtoRelationResponse
from rcabench.openapi.models.dto_relation_statistics_response import DtoRelationStatisticsResponse as DtoRelationStatisticsResponse
from rcabench.openapi.models.dto_remove_user_permission_request import DtoRemoveUserPermissionRequest as DtoRemoveUserPermissionRequest
from rcabench.openapi.models.dto_remove_user_role_request import DtoRemoveUserRoleRequest as DtoRemoveUserRoleRequest
from rcabench.openapi.models.dto_resource_response import DtoResourceResponse as DtoResourceResponse
from rcabench.openapi.models.dto_retry_policy import DtoRetryPolicy as DtoRetryPolicy
from rcabench.openapi.models.dto_role_list_response import DtoRoleListResponse as DtoRoleListResponse
from rcabench.openapi.models.dto_role_response import DtoRoleResponse as DtoRoleResponse
from rcabench.openapi.models.dto_role_search_request import DtoRoleSearchRequest as DtoRoleSearchRequest
from rcabench.openapi.models.dto_search_filter import DtoSearchFilter as DtoSearchFilter
from rcabench.openapi.models.dto_search_response_dto_algorithm_response import DtoSearchResponseDtoAlgorithmResponse as DtoSearchResponseDtoAlgorithmResponse
from rcabench.openapi.models.dto_search_response_dto_container_response import DtoSearchResponseDtoContainerResponse as DtoSearchResponseDtoContainerResponse
from rcabench.openapi.models.dto_search_response_dto_dataset_v2_response import DtoSearchResponseDtoDatasetV2Response as DtoSearchResponseDtoDatasetV2Response
from rcabench.openapi.models.dto_search_response_dto_permission_response import DtoSearchResponseDtoPermissionResponse as DtoSearchResponseDtoPermissionResponse
from rcabench.openapi.models.dto_search_response_dto_role_response import DtoSearchResponseDtoRoleResponse as DtoSearchResponseDtoRoleResponse
from rcabench.openapi.models.dto_search_response_dto_task_response import DtoSearchResponseDtoTaskResponse as DtoSearchResponseDtoTaskResponse
from rcabench.openapi.models.dto_search_response_dto_user_response import DtoSearchResponseDtoUserResponse as DtoSearchResponseDtoUserResponse
from rcabench.openapi.models.dto_service_coverage_item import DtoServiceCoverageItem as DtoServiceCoverageItem
from rcabench.openapi.models.dto_service_info import DtoServiceInfo as DtoServiceInfo
from rcabench.openapi.models.dto_size_range_filter import DtoSizeRangeFilter as DtoSizeRangeFilter
from rcabench.openapi.models.dto_sort_direction import DtoSortDirection as DtoSortDirection
from rcabench.openapi.models.dto_sort_option import DtoSortOption as DtoSortOption
from rcabench.openapi.models.dto_submit_dataset_building_req import DtoSubmitDatasetBuildingReq as DtoSubmitDatasetBuildingReq
from rcabench.openapi.models.dto_submit_execution_req import DtoSubmitExecutionReq as DtoSubmitExecutionReq
from rcabench.openapi.models.dto_submit_injection_req import DtoSubmitInjectionReq as DtoSubmitInjectionReq
from rcabench.openapi.models.dto_submit_injection_resp import DtoSubmitInjectionResp as DtoSubmitInjectionResp
from rcabench.openapi.models.dto_submit_resp import DtoSubmitResp as DtoSubmitResp
from rcabench.openapi.models.dto_successful_execution_item import DtoSuccessfulExecutionItem as DtoSuccessfulExecutionItem
from rcabench.openapi.models.dto_system_info import DtoSystemInfo as DtoSystemInfo
from rcabench.openapi.models.dto_system_statistics_response import DtoSystemStatisticsResponse as DtoSystemStatisticsResponse
from rcabench.openapi.models.dto_task_detail_resp import DtoTaskDetailResp as DtoTaskDetailResp
from rcabench.openapi.models.dto_task_detail_response import DtoTaskDetailResponse as DtoTaskDetailResponse
from rcabench.openapi.models.dto_task_item import DtoTaskItem as DtoTaskItem
from rcabench.openapi.models.dto_task_response import DtoTaskResponse as DtoTaskResponse
from rcabench.openapi.models.dto_task_search_request import DtoTaskSearchRequest as DtoTaskSearchRequest
from rcabench.openapi.models.dto_task_statistics import DtoTaskStatistics as DtoTaskStatistics
from rcabench.openapi.models.dto_token_refresh_request import DtoTokenRefreshRequest as DtoTokenRefreshRequest
from rcabench.openapi.models.dto_token_refresh_response import DtoTokenRefreshResponse as DtoTokenRefreshResponse
from rcabench.openapi.models.dto_trace import DtoTrace as DtoTrace
from rcabench.openapi.models.dto_trace_stats import DtoTraceStats as DtoTraceStats
from rcabench.openapi.models.dto_unified_task import DtoUnifiedTask as DtoUnifiedTask
from rcabench.openapi.models.dto_update_container_request import DtoUpdateContainerRequest as DtoUpdateContainerRequest
from rcabench.openapi.models.dto_update_permission_request import DtoUpdatePermissionRequest as DtoUpdatePermissionRequest
from rcabench.openapi.models.dto_update_role_request import DtoUpdateRoleRequest as DtoUpdateRoleRequest
from rcabench.openapi.models.dto_update_user_request import DtoUpdateUserRequest as DtoUpdateUserRequest
from rcabench.openapi.models.dto_user_info import DtoUserInfo as DtoUserInfo
from rcabench.openapi.models.dto_user_list_response import DtoUserListResponse as DtoUserListResponse
from rcabench.openapi.models.dto_user_project_response import DtoUserProjectResponse as DtoUserProjectResponse
from rcabench.openapi.models.dto_user_response import DtoUserResponse as DtoUserResponse
from rcabench.openapi.models.dto_user_search_request import DtoUserSearchRequest as DtoUserSearchRequest
from rcabench.openapi.models.dto_user_statistics import DtoUserStatistics as DtoUserStatistics
from rcabench.openapi.models.handler_groundtruth import HandlerGroundtruth as HandlerGroundtruth
from rcabench.openapi.models.handler_node import HandlerNode as HandlerNode
from rcabench.openapi.models.handler_pair import HandlerPair as HandlerPair
from rcabench.openapi.models.handler_resources import HandlerResources as HandlerResources



#!/usr/bin/env python3
"""
RCABench 客户端使用示例
"""

import sys
import os

sys.path.insert(0, os.path.join(os.path.dirname(__file__), "src"))

from rcabench_client import RCABenchClient
import rcabench.openapi


def example_with_statement():
    """使用 with 语句的示例"""
    print("=== 使用 with 语句 ===")

    with RCABenchClient() as api_client:
        # 获取任务列表
        task_api = rcabench.openapi.TaskApi(api_client)
        tasks = task_api.api_v1_tasks_get()
        print(f"任务数量: {len(tasks.data)}")

        # 获取容器列表
        container_api = rcabench.openapi.ContainersApi(api_client)
        containers = container_api.api_v2_containers_get()
        print(f"容器数量: {len(containers.data.items)}")


def example_direct_usage():
    """直接使用的示例"""
    print("\n=== 直接使用 ===")

    client = RCABenchClient()
    api_client = client.get_client()

    # 使用API客户端
    task_api = rcabench.openapi.TaskApi(api_client)
    tasks = task_api.api_v1_tasks_get()
    print(f"任务数量: {len(tasks.data)}")


def example_custom_config():
    """自定义配置的示例"""
    print("\n=== 自定义配置 ===")

    # 自定义服务器地址和凭据
    with RCABenchClient(
        base_url="http://10.10.10.46:8082", username="admin", password="admin123"
    ) as api_client:
        task_api = rcabench.openapi.TaskApi(api_client)
        tasks = task_api.api_v1_tasks_get()
        print(f"任务数量: {len(tasks.data)}")


if __name__ == "__main__":
    example_with_statement()
    example_direct_usage()
    example_custom_config()

    print("\n✅ 所有示例运行成功！")



#!/usr/bin/env python3
"""
RCABench 客户端
支持 with 语句的面向对象客户端
"""

import sys
import os

# 添加src目录到Python路径
sys.path.insert(0, os.path.join(os.path.dirname(__file__), "src"))

import rcabench.openapi
from rcabench.openapi.models.dto_login_request import DtoLoginRequest


class RCABenchClient:
    """RCABench API客户端，支持自动认证"""

    def __init__(
        self, base_url="http://10.10.10.46:8082", username="admin", password="admin123"
    ):
        self.base_url = base_url
        self.username = username
        self.password = password
        self.access_token = None
        self._api_client = None

    def __enter__(self):
        """进入上下文时自动登录并获取认证客户端"""
        self._login()
        return self._get_authenticated_client()

    def __exit__(self, exc_type, exc_val, exc_tb):
        """退出上下文时清理资源"""
        if self._api_client:
            # 如果需要的话，可以在这里添加清理逻辑
            pass

    def _login(self):
        """登录获取访问令牌"""
        if self.access_token:
            return

        config = rcabench.openapi.Configuration(host=self.base_url)
        with rcabench.openapi.ApiClient(config) as api_client:
            auth_api = rcabench.openapi.AuthenticationApi(api_client)
            login_request = DtoLoginRequest(
                username=self.username, password=self.password
            )
            response = auth_api.api_v2_auth_login_post(login_request)
            self.access_token = response.data.token

    def _get_authenticated_client(self):
        """获取已认证的API客户端"""
        if not self.access_token:
            self._login()

        # 创建带认证的配置
        auth_config = rcabench.openapi.Configuration(
            host=self.base_url,
            api_key={"BearerAuth": self.access_token},
            api_key_prefix={"BearerAuth": "Bearer"},
        )

        self._api_client = rcabench.openapi.ApiClient(auth_config)
        return self._api_client

    def get_client(self):
        """获取认证客户端（不自动登录）"""
        if not self._api_client:
            self._api_client = self._get_authenticated_client()
        return self._api_client


# 使用示例
if __name__ == "__main__":
    # 方式1: 使用 with 语句（推荐）
    with RCABenchClient() as api_client:
        print("✅ 获取到认证客户端")
        print(f"客户端类型: {type(api_client)}")

        # 使用客户端调用API
        task_api = rcabench.openapi.TaskApi(api_client)
        tasks = task_api.api_v1_tasks_get()
        print(f"任务数量: {len(tasks.data)}")

    # 方式2: 直接获取客户端
    client = RCABenchClient()
    api_client = client.get_client()
    print("✅ 直接获取认证客户端成功")



# Run this file:
# uv run pytest -s tests/test_trace_api.py
from pprint import pprint
from rcabench.model.trace import ExecutionOptions
import pytest


@pytest.mark.parametrize(
    "json_str",
    [
        (
            '{"algorithm":{"name":"traceback","image":"","tag":""},"dataset":"ts3-ts-order-service-return-qkcshv","execution_id":2314}'
        )
    ],
)
def test_ExecutionOptions(json_str: str) -> None:
    try:
        model = ExecutionOptions.model_validate_json(json_str)
        pprint(model)
    except Exception as e:
        pytest.fail(f"Failed to validate ExecutionOptions: {e}")
